/***

packet.h - external declarations for packet.c
           
Written by Gerard Paul Java

***/

void open_socket(int *fd, char *ifname);
void adjustpacket(char *tpacket, unsigned short family, char **packet,
		  int *readlen);
void getpacket(int fd, char *buf, struct sockaddr_pkt *fromaddr,
	       int *ch, int *br, unsigned long timeout, WINDOW * win);
